.. seealso:: 

    If you prefer to **install the GUI libraries manually**, these are the 
    pacakges required:

    .. tabs::

        .. tab:: conda
            
            .. code-block::
                
                conda install -c conda-forge pyqt
                conda install -c conda-forge qtpy
                conda install -c conda-forge pyqtgraph
                conda install -c conda-forge seaborn
                conda install -c conda-forge pytables

        
        .. tab:: pip
            
            .. code-block::
        
                pip install PyQt6==6.6.0 PyQt6-Qt6==6.6.0
                pip install qtpy
                pip install pyqtgraph
                pip install seaborn
                pip install tables
